pub enum Error {
IoError(Error),
RusqliteError(Error),
}Expand description
An error which can be returned when operating on the node database.
Variants
IoError(Error)
A standard I/O error was caught during operation on the node database. The actual error caught is returned as a payload of this variant.
RusqliteError(Error)
A Rusqlite error was caught during operation on the node database. The actual error caught is returned as a payload of this variant.